@@ -31,8 +31,9 @@ const unsigned int SayHello::BAD_COFFEE = 0xBADC0FFE;
 //------------------------------------------------------------------------------
 namespace hello
 {
-
-SayHello::SayHello() : text{"Hello, World!"}, value{0}
+SayHello::SayHello()
+    : text{"Hello, World!"}
+    , value{0}
 {
 }
 SayHello::~SayHello()
@@ -61,14 +62,16 @@ int main(int argc, char** argv)
     assert(42 == hello.get());
 
     // FizzBuzz
-    for(std::size_t i=1; i<=100; i++)
+    for(std::size_t i = 1; i <= 100; i++)
     {
         if((i % 15) == 0)
         {
             std::cout << "FizzBuzz\n";
         }
-        else if(i % 3 == 0) std::cout << "Fizz\n";
-        else if(i % 5 == 0) std::cout << "Buzz\n";
+        else if(i % 3 == 0)
+            std::cout << "Fizz\n";
+        else if(i % 5 == 0)
+            std::cout << "Buzz\n";
         else
         {
             std::cout << i << '\n';
