@@ -31,34 +31,32 @@ namespace NST
 {
 namespace analysis
 {
-
-
 bool NFSParser::parse_data(FilteredDataQueue::Ptr& ptr)
 {
     using namespace NST::protocols::rpc;
 
     // TODO: refactor and generalize this code
-    if (ptr->dlen < sizeof(MessageHeader))
+    if(ptr->dlen < sizeof(MessageHeader))
     {
         return false;
     }
     auto msg = reinterpret_cast<const MessageHeader*>(ptr->data);
-    switch (msg->type())
+    switch(msg->type())
     {
     case MsgType::CALL:
     {
-        if (ptr->dlen < sizeof(CallHeader))
+        if(ptr->dlen < sizeof(CallHeader))
         {
             return false;
         }
 
         auto call = static_cast<const CallHeader*>(msg);
 
-        if (RPCValidator::check(call) && (protocols::NFS4::Validator::check(call) ||
-                                          protocols::NFS3::Validator::check(call)))
+        if(RPCValidator::check(call) && (protocols::NFS4::Validator::check(call) ||
+                                         protocols::NFS3::Validator::check(call)))
         {
             Session* session = sessions.get_session(ptr->session, ptr->direction, MsgType::CALL);
-            if (session)
+            if(session)
             {
                 session->save_call_data(call->xid(), std::move(ptr));
             }
@@ -68,22 +66,22 @@ bool NFSParser::parse_data(FilteredDataQueue::Ptr& ptr)
     break;
     case MsgType::REPLY:
     {
-        if (ptr->dlen < sizeof(ReplyHeader))
+        if(ptr->dlen < sizeof(ReplyHeader))
         {
             return false;
         }
         auto reply = static_cast<const ReplyHeader*>(msg);
 
-        if (!RPCValidator::check(reply))
+        if(!RPCValidator::check(reply))
         {
             return false;
         }
 
         Session* session = sessions.get_session(ptr->session, ptr->direction, MsgType::REPLY);
-        if (session)
+        if(session)
         {
             FilteredDataQueue::Ptr&& call_data = session->get_call_data(reply->xid());
-            if (call_data)
+            if(call_data)
             {
                 analyze_nfs_procedure(std::move(call_data), std::move(ptr), session);
             }
@@ -104,35 +102,33 @@ static uint32_t get_nfs4_compound_minor_version(const uint32_t procedure, const
 using NFS40CompoundType = NST::protocols::NFS4::NFSPROC4RPCGEN_COMPOUND;
 using NFS41CompoundType = NST::protocols::NFS41::NFSPROC41RPCGEN_COMPOUND;
 
-template
-<
-typename ArgOpType,
-         typename ResOpType,
-         typename NFS4CompoundType
-         >
+template <
+    typename ArgOpType,
+    typename ResOpType,
+    typename NFS4CompoundType>
 void analyze_nfs4_operations(Analyzers& analyzers, NFS4CompoundType& nfs4_compound_procedure);
 
 inline void analyze_nfs40_operations(Analyzers& analyzers, NFS40CompoundType& nfs40_compound_procedure)
 {
-    analyze_nfs4_operations < NST::API::NFS4::nfs_argop4,
+    analyze_nfs4_operations<NST::API::NFS4::nfs_argop4,
                             NST::API::NFS4::nfs_resop4,
-                            NFS40CompoundType > (analyzers, nfs40_compound_procedure);
+                            NFS40CompoundType>(analyzers, nfs40_compound_procedure);
 }
 
 inline void analyze_nfs41_operations(Analyzers& analyzers, NFS41CompoundType& nfs41_compound_procedure)
 {
-    analyze_nfs4_operations < NST::API::NFS41::nfs_argop4,
+    analyze_nfs4_operations<NST::API::NFS41::nfs_argop4,
                             NST::API::NFS41::nfs_resop4,
-                            NFS41CompoundType > (analyzers, nfs41_compound_procedure);
+                            NFS41CompoundType>(analyzers, nfs41_compound_procedure);
 }
 
-void nfs4_ops_switch(Analyzers& analyzers,
-                     const RPCProcedure* rpc_procedure,
+void nfs4_ops_switch(Analyzers&                        analyzers,
+                     const RPCProcedure*               rpc_procedure,
                      const NST::API::NFS4::nfs_argop4* arg,
                      const NST::API::NFS4::nfs_resop4* res);
 
-void nfs4_ops_switch(Analyzers& analyzers,
-                     const RPCProcedure* rpc_procedure,
+void nfs4_ops_switch(Analyzers&                         analyzers,
+                     const RPCProcedure*                rpc_procedure,
                      const NST::API::NFS41::nfs_argop4* arg,
                      const NST::API::NFS41::nfs_resop4* res);
 
@@ -141,73 +137,73 @@ void nfs4_ops_switch(Analyzers& analyzers,
 static inline void analyze_nfsv3_procedure(const uint32_t procedure, XDRDecoder&& c, XDRDecoder&& r, const Session* s, Analyzers& analyzers)
 {
     using namespace NST::protocols::NFS3;
-    switch (procedure)
+    switch(procedure)
     {
     case ProcEnumNFS3::NFS_NULL:
-        analyzers(&IAnalyzer::INFSv3rpcgen::null,       NFSPROC3RPCGEN_NULL       {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::null, NFSPROC3RPCGEN_NULL{c, r, s});
         break;
     case ProcEnumNFS3::GETATTR:
-        analyzers(&IAnalyzer::INFSv3rpcgen::getattr3,   NFSPROC3RPCGEN_GETATTR    {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::getattr3, NFSPROC3RPCGEN_GETATTR{c, r, s});
         break;
     case ProcEnumNFS3::SETATTR:
-        analyzers(&IAnalyzer::INFSv3rpcgen::setattr3,   NFSPROC3RPCGEN_SETATTR    {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::setattr3, NFSPROC3RPCGEN_SETATTR{c, r, s});
         break;
     case ProcEnumNFS3::LOOKUP:
-        analyzers(&IAnalyzer::INFSv3rpcgen::lookup3,    NFSPROC3RPCGEN_LOOKUP     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::lookup3, NFSPROC3RPCGEN_LOOKUP{c, r, s});
         break;
     case ProcEnumNFS3::ACCESS:
-        analyzers(&IAnalyzer::INFSv3rpcgen::access3,    NFSPROC3RPCGEN_ACCESS     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::access3, NFSPROC3RPCGEN_ACCESS{c, r, s});
         break;
     case ProcEnumNFS3::READLINK:
-        analyzers(&IAnalyzer::INFSv3rpcgen::readlink3,  NFSPROC3RPCGEN_READLINK   {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::readlink3, NFSPROC3RPCGEN_READLINK{c, r, s});
         break;
     case ProcEnumNFS3::READ:
-        analyzers(&IAnalyzer::INFSv3rpcgen::read3,      NFSPROC3RPCGEN_READ       {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::read3, NFSPROC3RPCGEN_READ{c, r, s});
         break;
     case ProcEnumNFS3::WRITE:
-        analyzers(&IAnalyzer::INFSv3rpcgen::write3,     NFSPROC3RPCGEN_WRITE      {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::write3, NFSPROC3RPCGEN_WRITE{c, r, s});
         break;
     case ProcEnumNFS3::CREATE:
-        analyzers(&IAnalyzer::INFSv3rpcgen::create3,    NFSPROC3RPCGEN_CREATE     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::create3, NFSPROC3RPCGEN_CREATE{c, r, s});
         break;
     case ProcEnumNFS3::MKDIR:
-        analyzers(&IAnalyzer::INFSv3rpcgen::mkdir3,     NFSPROC3RPCGEN_MKDIR      {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::mkdir3, NFSPROC3RPCGEN_MKDIR{c, r, s});
         break;
     case ProcEnumNFS3::SYMLINK:
-        analyzers(&IAnalyzer::INFSv3rpcgen::symlink3,   NFSPROC3RPCGEN_SYMLINK    {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::symlink3, NFSPROC3RPCGEN_SYMLINK{c, r, s});
         break;
     case ProcEnumNFS3::MKNOD:
-        analyzers(&IAnalyzer::INFSv3rpcgen::mknod3,     NFSPROC3RPCGEN_MKNOD      {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::mknod3, NFSPROC3RPCGEN_MKNOD{c, r, s});
         break;
     case ProcEnumNFS3::REMOVE:
-        analyzers(&IAnalyzer::INFSv3rpcgen::remove3,    NFSPROC3RPCGEN_REMOVE     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::remove3, NFSPROC3RPCGEN_REMOVE{c, r, s});
         break;
     case ProcEnumNFS3::RMDIR:
-        analyzers(&IAnalyzer::INFSv3rpcgen::rmdir3,     NFSPROC3RPCGEN_RMDIR      {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::rmdir3, NFSPROC3RPCGEN_RMDIR{c, r, s});
         break;
     case ProcEnumNFS3::RENAME:
-        analyzers(&IAnalyzer::INFSv3rpcgen::rename3,    NFSPROC3RPCGEN_RENAME     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::rename3, NFSPROC3RPCGEN_RENAME{c, r, s});
         break;
     case ProcEnumNFS3::LINK:
-        analyzers(&IAnalyzer::INFSv3rpcgen::link3,      NFSPROC3RPCGEN_LINK       {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::link3, NFSPROC3RPCGEN_LINK{c, r, s});
         break;
     case ProcEnumNFS3::READDIR:
-        analyzers(&IAnalyzer::INFSv3rpcgen::readdir3,   NFSPROC3RPCGEN_READDIR    {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::readdir3, NFSPROC3RPCGEN_READDIR{c, r, s});
         break;
     case ProcEnumNFS3::READDIRPLUS:
-        analyzers(&IAnalyzer::INFSv3rpcgen::readdirplus3, NFSPROC3RPCGEN_READDIRPLUS {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::readdirplus3, NFSPROC3RPCGEN_READDIRPLUS{c, r, s});
         break;
     case ProcEnumNFS3::FSSTAT:
-        analyzers(&IAnalyzer::INFSv3rpcgen::fsstat3,    NFSPROC3RPCGEN_FSSTAT     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::fsstat3, NFSPROC3RPCGEN_FSSTAT{c, r, s});
         break;
     case ProcEnumNFS3::FSINFO:
-        analyzers(&IAnalyzer::INFSv3rpcgen::fsinfo3,    NFSPROC3RPCGEN_FSINFO     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::fsinfo3, NFSPROC3RPCGEN_FSINFO{c, r, s});
         break;
     case ProcEnumNFS3::PATHCONF:
-        analyzers(&IAnalyzer::INFSv3rpcgen::pathconf3,  NFSPROC3RPCGEN_PATHCONF   {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::pathconf3, NFSPROC3RPCGEN_PATHCONF{c, r, s});
         break;
     case ProcEnumNFS3::COMMIT:
-        analyzers(&IAnalyzer::INFSv3rpcgen::commit3,    NFSPROC3RPCGEN_COMMIT     {c, r, s});
+        analyzers(&IAnalyzer::INFSv3rpcgen::commit3, NFSPROC3RPCGEN_COMMIT{c, r, s});
         break;
     }
 }
@@ -217,25 +213,25 @@ static inline void analyze_nfsv4_procedure(const uint32_t procedure, XDRDecoder&
     using namespace NST::protocols::NFS4;
     using namespace NST::protocols::NFS41;
 
-    switch (get_nfs4_compound_minor_version(procedure, c.data().data))
+    switch(get_nfs4_compound_minor_version(procedure, c.data().data))
     {
     case NFS_V40:
-        switch (procedure)
+        switch(procedure)
         {
         case ProcEnumNFS4::NFS_NULL:
-            analyzers(&IAnalyzer::INFSv4rpcgen::null4, NFSPROC4RPCGEN_NULL { c, r, s });
+            analyzers(&IAnalyzer::INFSv4rpcgen::null4, NFSPROC4RPCGEN_NULL{c, r, s});
             break;
         case ProcEnumNFS4::COMPOUND:
-            NFSPROC4RPCGEN_COMPOUND compound { c, r, s };
+            NFSPROC4RPCGEN_COMPOUND compound{c, r, s};
             analyzers(&IAnalyzer::INFSv4rpcgen::compound4, compound);
             analyze_nfs40_operations(analyzers, compound);
             break;
         }
         break;
     case NFS_V41:
-        if (ProcEnumNFS41::COMPOUND == procedure)
+        if(ProcEnumNFS41::COMPOUND == procedure)
         {
-            NFSPROC41RPCGEN_COMPOUND compound { c, r, s };
+            NFSPROC41RPCGEN_COMPOUND compound{c, r, s};
             analyzers(&IAnalyzer::INFSv41rpcgen::compound41, compound);
             analyze_nfs41_operations(analyzers, compound);
         }
@@ -243,21 +239,21 @@ static inline void analyze_nfsv4_procedure(const uint32_t procedure, XDRDecoder&
     }
 }
 
-void NFSParser::analyze_nfs_procedure( FilteredDataQueue::Ptr&& call,
-                                       FilteredDataQueue::Ptr&& reply,
-                                       Session* session)
+void NFSParser::analyze_nfs_procedure(FilteredDataQueue::Ptr&& call,
+                                      FilteredDataQueue::Ptr&& reply,
+                                      Session*                 session)
 {
     using namespace NST::protocols::rpc;
 
-    auto header = reinterpret_cast<const CallHeader*>(call->data);
-    const uint32_t major_version {header->vers()};
-    const uint32_t procedure {header->proc()};
+    auto           header = reinterpret_cast<const CallHeader*>(call->data);
+    const uint32_t major_version{header->vers()};
+    const uint32_t procedure{header->proc()};
 
     try
     {
-        const Session* s { session->get_session() };
+        const Session* s{session->get_session()};
 
-        switch (major_version)
+        switch(major_version)
         {
         case NFS_V4:
             analyze_nfsv4_procedure(procedure, std::move(call), std::move(reply), s, this->analyzers);
@@ -267,10 +263,10 @@ void NFSParser::analyze_nfs_procedure( FilteredDataQueue::Ptr&& call,
             break;
         }
     }
-    catch (XDRDecoderError& e)
+    catch(XDRDecoderError& e)
     {
-        const char* procedure_name {"Unknown procedure"};
-        switch (major_version)
+        const char* procedure_name{"Unknown procedure"};
+        switch(major_version)
         {
         case NFS_V4:
             procedure_name = print_nfs4_procedures(static_cast<ProcEnumNFS4::NFSProcedure>(procedure));
@@ -294,7 +290,7 @@ void NFSParser::analyze_nfs_procedure( FilteredDataQueue::Ptr&& call,
 */
 static uint32_t get_nfs4_compound_minor_version(const uint32_t procedure, const std::uint8_t* rpc_nfs4_call)
 {
-    if (ProcEnumNFS4::COMPOUND != procedure)
+    if(ProcEnumNFS4::COMPOUND != procedure)
     {
         return 0;
     }
@@ -321,40 +317,39 @@ static uint32_t get_nfs4_compound_minor_version(const uint32_t procedure, const
 
 //! Common internal function for parsing NFSv4.x's COMPOUND procedure
 //! It's supposed to be used inside analyze_nfs_procedure only
-template
-<
-typename ArgOpType,       // Type of arguments(call part of nfs's procedure)
-         typename ResOpType,       // Type of results(reply part of nfs's procedure)
-         typename NFS4CompoundType // Type of NFSv4.x COMPOUND procedure. Can be 4.0 or 4.1
-         >
+template <
+    typename ArgOpType,       // Type of arguments(call part of nfs's procedure)
+    typename ResOpType,       // Type of results(reply part of nfs's procedure)
+    typename NFS4CompoundType // Type of NFSv4.x COMPOUND procedure. Can be 4.0 or 4.1
+    >
 void analyze_nfs4_operations(Analyzers& analyzers, NFS4CompoundType& nfs4_compound_procedure)
 {
-    ArgOpType* arg {nullptr};
-    ResOpType* res {nullptr};
+    ArgOpType* arg{nullptr};
+    ResOpType* res{nullptr};
 
-    uint32_t arg_ops_count  {0}; // Amount of NFS operations (call part)
-    uint32_t res_ops_count  {0}; // Amount of NFS operations (reply part)
-    uint32_t total_ops_count {0};
+    uint32_t arg_ops_count{0}; // Amount of NFS operations (call part)
+    uint32_t res_ops_count{0}; // Amount of NFS operations (reply part)
+    uint32_t total_ops_count{0};
 
-    if (nfs4_compound_procedure.parg) // Checking if COMPOUND procedure has valid arg
+    if(nfs4_compound_procedure.parg) // Checking if COMPOUND procedure has valid arg
     {
         arg_ops_count = nfs4_compound_procedure.parg->argarray.argarray_len;
-        arg = nfs4_compound_procedure.parg->argarray.argarray_val;
+        arg           = nfs4_compound_procedure.parg->argarray.argarray_val;
     }
 
-    if (nfs4_compound_procedure.pres) // Checking if COMPOUND procedure has valid res
+    if(nfs4_compound_procedure.pres) // Checking if COMPOUND procedure has valid res
     {
         res_ops_count = nfs4_compound_procedure.pres->resarray.resarray_len;
-        res = nfs4_compound_procedure.pres->resarray.resarray_val;
+        res           = nfs4_compound_procedure.pres->resarray.resarray_val;
     }
 
     // Determing which part of COMPOUND has the biggest amount of operations.
     total_ops_count = arg_ops_count > res_ops_count ? arg_ops_count : res_ops_count;
 
     // Traversing through ALL COMPOUND procedure's operations
-    for (uint32_t i {0}; i < total_ops_count; i++)
+    for(uint32_t i{0}; i < total_ops_count; i++)
     {
-        if ((arg && res) && (arg->argop != res->resop))
+        if((arg && res) && (arg->argop != res->resop))
         {
             // Passing each operation to analyzers using the helper's function
             nfs4_ops_switch(analyzers, &nfs4_compound_procedure, arg, nullptr);
@@ -365,58 +360,66 @@ void analyze_nfs4_operations(Analyzers& analyzers, NFS4CompoundType& nfs4_compou
             nfs4_ops_switch(analyzers, &nfs4_compound_procedure, arg, res);
         }
 
-        if (arg && i < (arg_ops_count - 1)) { arg++; }
-        else { arg = nullptr; }
-        if (res && i < (res_ops_count - 1)) { res++; }
-        else { res = nullptr; }
+        if(arg && i < (arg_ops_count - 1))
+        {
+            arg++;
+        }
+        else
+        {
+            arg = nullptr;
+        }
+        if(res && i < (res_ops_count - 1))
+        {
+            res++;
+        }
+        else
+        {
+            res = nullptr;
+        }
     }
 }
 
 //! Internal function for proper passing NFSv4.x's arg + res operations to analyzers
 //! It's supposed to be used inside nfs4_ops_switch only
-template
-<
-typename nfs_argop4_t,
-         typename nfs_resop4_t,
-         typename IAnalyzer_func_t,
-         typename nfs_argop_member_t,
-         typename nfs_resop_member_t
-         >
-inline void analyze(Analyzers& analyzers,
+template <
+    typename nfs_argop4_t,
+    typename nfs_resop4_t,
+    typename IAnalyzer_func_t,
+    typename nfs_argop_member_t,
+    typename nfs_resop_member_t>
+inline void analyze(Analyzers&          analyzers,
                     const RPCProcedure* rpc_procedure,
                     const nfs_argop4_t* arg,
                     const nfs_resop4_t* res,
-                    IAnalyzer_func_t&& IAnalyzer_function,
-                    nfs_argop_member_t arg_operation,
-                    nfs_resop_member_t res_operation)
+                    IAnalyzer_func_t&&  IAnalyzer_function,
+                    nfs_argop_member_t  arg_operation,
+                    nfs_resop_member_t  res_operation)
 {
     analyzers(IAnalyzer_function, rpc_procedure,
-              arg == nullptr ? nullptr : & (arg->nfs_argop4_u.*arg_operation),
-              res == nullptr ? nullptr : & (res->nfs_resop4_u.*res_operation));
+              arg == nullptr ? nullptr : &(arg->nfs_argop4_u.*arg_operation),
+              res == nullptr ? nullptr : &(res->nfs_resop4_u.*res_operation));
 }
 
 //! Internal function for proper passing NFSv4.x's res-only operations to analyzers
 //! It's supposed to be used inside nfs4_ops_switch only
-template
-<
-typename nfs_resop4_t,
-         typename IAnalyzer_func_t,
-         typename nfs_resop_member_t
-         >
-inline void analyze(Analyzers& analyzers,
+template <
+    typename nfs_resop4_t,
+    typename IAnalyzer_func_t,
+    typename nfs_resop_member_t>
+inline void analyze(Analyzers&          analyzers,
                     const RPCProcedure* rpc_procedure,
                     const nfs_resop4_t* res,
-                    IAnalyzer_func_t&& IAnalyzer_function,
-                    nfs_resop_member_t res_operation)
+                    IAnalyzer_func_t&&  IAnalyzer_function,
+                    nfs_resop_member_t  res_operation)
 {
     analyzers(IAnalyzer_function, rpc_procedure,
-              res == nullptr ? nullptr : & (res->nfs_resop4_u.*res_operation));
+              res == nullptr ? nullptr : &(res->nfs_resop4_u.*res_operation));
 }
 
 //! Internal function for proper passing NFSv4.0's operations to analyzers
 //! It's supposed to be used inside analyze_nfs4_operations only
-void nfs4_ops_switch(Analyzers& analyzers,
-                     const RPCProcedure* rpc_procedure,
+void nfs4_ops_switch(Analyzers&                        analyzers,
+                     const RPCProcedure*               rpc_procedure,
                      const NST::API::NFS4::nfs_argop4* arg,
                      const NST::API::NFS4::nfs_resop4* res)
 {
@@ -425,7 +428,7 @@ void nfs4_ops_switch(Analyzers& analyzers,
     using res_t   = NST::API::NFS4::nfs_resop4_u_t;
 
     uint32_t nfs_op_num = arg ? arg->argop : res->resop;
-    switch (nfs_op_num)
+    switch(nfs_op_num)
     {
     case ProcEnumNFS4::ACCESS:
         analyze(analyzers, rpc_procedure, arg, res,
@@ -660,8 +663,8 @@ void nfs4_ops_switch(Analyzers& analyzers,
 
 //! Internal function for proper passing NFSv4.1's operations to analyzers
 //! It's supposed to be used inside analyze_nfs4_operations only
-void nfs4_ops_switch(Analyzers& analyzers,
-                     const RPCProcedure* rpc_procedure,
+void nfs4_ops_switch(Analyzers&                         analyzers,
+                     const RPCProcedure*                rpc_procedure,
                      const NST::API::NFS41::nfs_argop4* arg,
                      const NST::API::NFS41::nfs_resop4* res)
 {
@@ -670,7 +673,7 @@ void nfs4_ops_switch(Analyzers& analyzers,
     using res_t   = NST::API::NFS41::nfs_resop4_u_t;
 
     uint32_t nfs_op_num = arg ? arg->argop : res->resop;
-    switch (nfs_op_num)
+    switch(nfs_op_num)
     {
     case ProcEnumNFS41::ACCESS:
         analyze(analyzers, rpc_procedure, arg, res,
